@@ -13,14 +13,19 @@
 # limitations under the License.
 
 import nuclio_sdk
+import nuclio_sdk.event
 
 
 class Context(object):
 
-    def __init__(self, logger=None, platform=None, worker_id=None, trigger_name=None):
+    def __init__(self, logger=None, platform=None, worker_id=None, trigger=None):
         self.platform = platform or nuclio_sdk.Platform('test')
         self.logger = logger
         self.user_data = lambda: None
         self.Response = nuclio_sdk.Response
         self.worker_id = worker_id
-        self.trigger_name = trigger_name
+        self.trigger = trigger
+
+        # for backwards compatibility
+        if self.trigger is not None:
+            self.trigger_name = self.trigger.name
