@@ -57,6 +57,7 @@ class Logger(object):
     def __init__(self, level):
         self._logger = logging.getLogger('nuclio_sdk')
         self._logger.setLevel(level)
+        self._bound_variables = {}
         self._handlers = {}
 
     def set_handler(self, handler_name, file, formatter):
@@ -65,7 +66,7 @@ class Logger(object):
         if handler_name in self._handlers:
 
             # log that we're removing it
-            self.info_with('Replacing logger output')
+            self.info('Replacing logger output')
 
             self._logger.removeHandler(self._handlers[handler_name])
 
@@ -82,25 +83,37 @@ class Logger(object):
         self._handlers[handler_name] = stream_handler
 
     def debug(self, message, *args):
-        self._logger.debug(message, *args)
+        self._update_bound_vars_and_log(logging.DEBUG, message, *args)
 
     def info(self, message, *args):
-        self._logger.info(message, *args)
+        self._update_bound_vars_and_log(logging.INFO, message, *args)
 
     def warn(self, message, *args):
-        self._logger.warning(message, *args)
+        self._update_bound_vars_and_log(logging.WARNING, message, *args)
 
     def error(self, message, *args):
-        self._logger.error(message, *args)
+        self._update_bound_vars_and_log(logging.ERROR, message, *args)
 
     def debug_with(self, message, *args, **kw_args):
-        self._logger.debug(message, *args, extra={'with': kw_args})
+        self._update_bound_vars_and_log(logging.DEBUG, message, *args, **kw_args)
 
     def info_with(self, message, *args, **kw_args):
-        self._logger.info(message, *args, extra={'with': kw_args})
+        self._update_bound_vars_and_log(logging.INFO, message, *args, **kw_args)
 
     def warn_with(self, message, *args, **kw_args):
-        self._logger.warning(message, *args, extra={'with': kw_args})
+        self._update_bound_vars_and_log(logging.WARNING, message, *args, **kw_args)
 
     def error_with(self, message, *args, **kw_args):
-        self._logger.error(message, *args, extra={'with': kw_args})
+        self._update_bound_vars_and_log(logging.ERROR, message, *args, **kw_args)
+
+    def bind(self, **kw_args):
+        self._bound_variables.update(kw_args)
+
+    def _update_bound_vars_and_log(self, level, message, *args, **kw_args):
+        kw_args.update(self._bound_variables)
+
+        if len(kw_args) != 0:
+            self._logger._log(level, message, args, extra={'with': kw_args})
+            return
+
+        self._logger._log(level, message, args)
